@@ -8,10 +8,10 @@
 
 typedef enum direction { north, east, south, west } direction_t;
 
-extern id <Symbol>  S1;
+externvar id <Symbol>S1;
 
-extern id <Warning> W1;
+externvar id <Warning>W1;
 
-extern id <Error>   E1;
+externvar id <Error>E1;
 
 #import "grid.xt"
